/* DO NOT EDIT THIS FILE - it is machine generated */
#include "jni.h"

/* Header for class netscape_javascript_JSException */

#ifndef _Included_netscape_javascript_JSException
#define _Included_netscape_javascript_JSException
#ifdef __cplusplus
extern "C" {
#endif
#ifdef __cplusplus
}
#endif
#endif
