/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /builds/tinderbox/XR-Trunk/Linux_2.6.18-8.el5_Depend/mozilla/accessible/public/nsIAccessibleHyperText.idl
 */

#ifndef __gen_nsIAccessibleHyperText_h__
#define __gen_nsIAccessibleHyperText_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

#ifndef __gen_nsIAccessibleHyperLink_h__
#include "nsIAccessibleHyperLink.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIAccessibleHyperText */
#define NS_IACCESSIBLEHYPERTEXT_IID_STR "dec56474-2887-4d44-9826-1594cfe4a2f4"

#define NS_IACCESSIBLEHYPERTEXT_IID \
  {0xdec56474, 0x2887, 0x4d44, \
    { 0x98, 0x26, 0x15, 0x94, 0xcf, 0xe4, 0xa2, 0xf4 }}

class NS_NO_VTABLE NS_SCRIPTABLE nsIAccessibleHyperText : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IACCESSIBLEHYPERTEXT_IID)

  /* readonly attribute long links; */
  NS_SCRIPTABLE NS_IMETHOD GetLinks(PRInt32 *aLinks) = 0;

  /* nsIAccessibleHyperLink getLink (in long index); */
  NS_SCRIPTABLE NS_IMETHOD GetLink(PRInt32 index, nsIAccessibleHyperLink **_retval) = 0;

  /* long getLinkIndex (in long charIndex); */
  NS_SCRIPTABLE NS_IMETHOD GetLinkIndex(PRInt32 charIndex, PRInt32 *_retval) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIAccessibleHyperText, NS_IACCESSIBLEHYPERTEXT_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIACCESSIBLEHYPERTEXT \
  NS_SCRIPTABLE NS_IMETHOD GetLinks(PRInt32 *aLinks); \
  NS_SCRIPTABLE NS_IMETHOD GetLink(PRInt32 index, nsIAccessibleHyperLink **_retval); \
  NS_SCRIPTABLE NS_IMETHOD GetLinkIndex(PRInt32 charIndex, PRInt32 *_retval); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIACCESSIBLEHYPERTEXT(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetLinks(PRInt32 *aLinks) { return _to GetLinks(aLinks); } \
  NS_SCRIPTABLE NS_IMETHOD GetLink(PRInt32 index, nsIAccessibleHyperLink **_retval) { return _to GetLink(index, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetLinkIndex(PRInt32 charIndex, PRInt32 *_retval) { return _to GetLinkIndex(charIndex, _retval); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIACCESSIBLEHYPERTEXT(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetLinks(PRInt32 *aLinks) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetLinks(aLinks); } \
  NS_SCRIPTABLE NS_IMETHOD GetLink(PRInt32 index, nsIAccessibleHyperLink **_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetLink(index, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD GetLinkIndex(PRInt32 charIndex, PRInt32 *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetLinkIndex(charIndex, _retval); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsAccessibleHyperText : public nsIAccessibleHyperText
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIACCESSIBLEHYPERTEXT

  nsAccessibleHyperText();

private:
  ~nsAccessibleHyperText();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsAccessibleHyperText, nsIAccessibleHyperText)

nsAccessibleHyperText::nsAccessibleHyperText()
{
  /* member initializers and constructor code */
}

nsAccessibleHyperText::~nsAccessibleHyperText()
{
  /* destructor code */
}

/* readonly attribute long links; */
NS_IMETHODIMP nsAccessibleHyperText::GetLinks(PRInt32 *aLinks)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* nsIAccessibleHyperLink getLink (in long index); */
NS_IMETHODIMP nsAccessibleHyperText::GetLink(PRInt32 index, nsIAccessibleHyperLink **_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long getLinkIndex (in long charIndex); */
NS_IMETHODIMP nsAccessibleHyperText::GetLinkIndex(PRInt32 charIndex, PRInt32 *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIAccessibleHyperText_h__ */
